{% extends "admin/base_site.html" %}
{% load i18n admin_urls admin_static admin_list %}

{% block title %}{% trans "uWSGI Stats" %}{% endblock %}

{% block extrastyle %}
    {{ block.super }}
    <link rel="stylesheet" type="text/css" href="{% static "admin/css/forms.css" %}">
{% endblock %}

{% if not is_popup %}
{% block breadcrumbs %}
<div class="breadcrumbs">
<a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
&rsaquo; <a href="{% url 'uwsgi_index' %}">{% trans "uWSGI" %}</a>
&rsaquo; {% trans "Status" %}
</div>
{% endblock %}
{% endif %}


{% block bodyclass %}{{ block.super }} app-django_uwsgi model-status change-list{% endblock %}

{% block coltype %}flex{% endblock %}

{% block content %}
    {% include "uwsgi/panel.html" %}
{% endblock %}
